@@ -29,16 +29,8 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
-#if 0 /* xml-config , gnome-config --libs xml & pkg-config --libs xml are all broKEN
-	  * i sent a patch to the list xml@gnome.org for now deal with their brokenes
-	  * Chema
-	  */
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
-#else
-#include <parser.h>
-#include <xmlmemory.h>
-#endif
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 
 #include <mtm/mtm-theme.h>
 #include <mtm/mtm-ext-handler.h>
@@ -396,11 +388,11 @@ mtm_theme_construct_extension_from_node (xmlNodePtr node, MtmEnv *env, const gch
 	g_free (type);
 	ext->file = file;
 	
-	if (node->childs && ext->handler)
+	if (node->children && ext->handler)
 	{
 		gtk_object_set (GTK_OBJECT (ext->handler),
 					 "ext_context", ext, NULL);
-		parse_args (ext, node->childs);
+		parse_args (ext, node->children);
 	}
 	
 	return ext;
@@ -424,37 +416,37 @@ mtm_theme_construct_from_file (MtmTheme *theme, MtmEnv *env, const gchar *filena
 	g_return_if_fail (doc != NULL);
 	
 	/* MEMLEAK */
-	node = doc->root;
+	node = doc->children;
 	g_return_if_fail (node != NULL);
-	g_return_if_fail (strcasecmp (node->childs->name, "metatheme") != 0);
+	g_return_if_fail (strcasecmp (node->children->name, "metatheme") != 0);
 
 	theme->priv->exts = NULL;
 	
-	node = node->childs;
+	node = node->children;
 	
 	while (node != NULL)
 	{
 		if (strcasecmp (node->name, "name") == 0)
 		{
-			char *tmp = xmlNodeListGetString (doc, node->childs, 1);
+			char *tmp = xmlNodeListGetString (doc, node->children, 1);
 			theme->name = g_strdup (tmp);
 			xmlFree (tmp);
 		}
 		else if (strcasecmp (node->name, "desc") == 0)
 		{
-			char *tmp = xmlNodeListGetString (doc, node->childs, 1);
+			char *tmp = xmlNodeListGetString (doc, node->children, 1);
 			theme->desc = g_strdup (tmp);
 			xmlFree (tmp);
 		}
 		else if (strcasecmp (node->name, "preview") == 0)
 		{
-			char *tmp = xmlNodeListGetString (doc, node->childs, 1);
+			char *tmp = xmlNodeListGetString (doc, node->children, 1);
 			theme->preview = g_strconcat (filename, "/", tmp, NULL);
 			xmlFree (tmp);
 		}
 		else if (strcasecmp (node->name, "author") == 0)
 		{
-			char *tmp = xmlNodeListGetString (doc, node->childs, 1);
+			char *tmp = xmlNodeListGetString (doc, node->children, 1);
 			char *email = xmlGetProp (node, "email");
 			theme->author= g_strdup (tmp);
 			xmlFree (tmp);
@@ -566,8 +558,7 @@ mtm_theme_save_as (MtmTheme *theme, gchar *filename)
 		{
 			char *tmp = g_strconcat (indent, "\t", NULL);
 			guint n, i;
-			GtkArg *args;
-			GtkArg tmparg;
+			GParamSpec **args;
 			args = ext->handler->subclass_args;
 			n = ext->handler->n_subclass_args;
 			
@@ -578,13 +569,13 @@ mtm_theme_save_as (MtmTheme *theme, gchar *filename)
 
 			for (i = 0; i < n; i++)
 			{
+				GValue tmparg = { 0, };
+
 				fprintf (file, "%s<arg name=\"%s\" ",
-					tmp,
-					mtm_ext_handler_get_arg_name (ext->handler, args[i].name));
-				tmparg.name = args[i].name;
-				tmparg.type = args[i].type;
-				gtk_object_getv (GTK_OBJECT (ext->handler),
-					1, &tmparg);
+					tmp, args[i]->name);
+				g_value_init (&tmparg, args[i]->value_type);
+				g_object_get_property (G_OBJECT (ext->handler),
+					args[i]->name, &tmparg);
 				mtm_ext_handler_print_arg (ext->handler,
 					file, &tmparg);
 				fprintf (file, "/>\n");
@@ -809,15 +800,15 @@ parse_args (MtmExt *ext, xmlNodePtr node)
 {
 	GdkColor color;
 	GtkType type;
-	GtkArg arg;
 	gchar *typename;
-	gchar *tmp;
+	gchar *tmp, *name;
 
 	while (node != NULL)
 	{
 		if (strcasecmp (node->name, "arg") == 0)
 		{
 			char *xmltmp;
+			GValue arg = { 0, };
 			
 			typename = xmlGetProp (node, "type");
 			type = gtk_type_from_name (typename);
@@ -827,25 +818,34 @@ parse_args (MtmExt *ext, xmlNodePtr node)
 				node = node->next;
 				continue;
 			}
-			arg.type = type;
 			xmltmp = xmlGetProp (node, "name");
-			arg.name = g_strdup (xmltmp);
+			name = g_strdup (xmltmp);
 			xmlFree (xmltmp);
 			tmp = xmlGetProp (node, "value");
 			if (type == GTK_TYPE_STRING)
-				GTK_VALUE_STRING (arg) = tmp;
-			else if (type == GTK_TYPE_BOOL)
-				GTK_VALUE_BOOL (arg) = (tmp[0] != '0');
-			else if (type == GTK_TYPE_GDK_COLOR)
 			{
+				g_value_init (&arg, GTK_TYPE_STRING);
+				g_value_set_string (&arg, tmp);
+			}
+			else if (type == GTK_TYPE_BOOL)
+			{
+				g_value_init (&arg, GTK_TYPE_BOOL);
+				g_value_set_boolean (&arg, tmp[0] != '0');
+			}
+			else if (type == GDK_TYPE_COLOR)
+			{
+				g_value_init (&arg, GDK_TYPE_COLOR);
 				gdk_color_parse (tmp, &color);
-				GTK_VALUE_BOXED (arg) = &color;
+				g_value_set_boxed (&arg, &color);
 			}
 			else
-				GTK_VALUE_ENUM (arg) = atoi (tmp);
+			{
+				g_value_init (&arg, type); 
+				g_value_set_enum (&arg, atoi (tmp));
+			}
 
-			gtk_object_setv (GTK_OBJECT (ext->handler), 1, &arg);
-			g_free (arg.name);
+			g_object_set_property (G_OBJECT (ext->handler), name, &arg);
+			g_free (name);
 			xmlFree (tmp);
 			xmlFree (typename);
 		}
@@ -857,7 +857,7 @@ gint
 mtm_theme_compare (gconstpointer a, gconstpointer b)
 {
 	const MtmTheme *theme1, *theme2;
-	gchar *str1, *str2;
+	const gchar *str1, *str2;
 	
 	theme1 = a;
 	theme2 = b;
